@@ -222,10 +222,14 @@ def get_method_argparser(view, args, cl_core = False):
                     data['type'] = str
                 if field.element in ['check', 'check_tristate']:
                     data['action'] = BoolAction
+                    if field.value == 'on':
+                        data['help'] = data['help'] + " " + _("(enabled by default)")
                     if opt.shortopt:
                         boolVars.append(opt.shortopt[1])
                 elif field.element == 'radio' and field.type == 'bool':
                     data['action'] = BoolAction
+                    if field.value == 'on':
+                        data['help'] = data['help'] + " " + _("(enabled by default)")
                     if opt.shortopt:
                         boolVars.append(opt.shortopt[1])
                 if field.element == 'table' and field.type != 'steps':
